testEquivalentMetadata: Test that metadata of 2 or more objects is the same

View source: R/spread3.R

testEquivalentMetadataR Documentation

Test that metadata of 2 or more objects is the same

Description

Currently, only Raster class has a useful method. Defaults to all(sapply(list(...)[-1], function(x) identical(list(...)[1], x)))

Usage

testEquivalentMetadata(...)

Arguments

...

2 or more of the same type of object to test for equivalent metadata.

Value

Invisible NULL. Called for its side effect: it signals an error if the objects' metadata are not equivalent, and returns silently if they are.


SpaDES.tools documentation built on Aug. 29, 2026, 1:07 a.m.