Learn R Programming

SpaDES.tools (version 2.1.3)

transitions: SELES - Transitioning to next time step (defunct)

Description

This function was never fully implemented and is now defunct: calling it signals an error.

It was intended to describe the probability of an agent successfully persisting until the next time step, as a SELES-like function maintaining conceptual backwards compatibility with SELES. The implementation it carried could not work -- it assigned into sp::coordinates(agent), which errors on any Spatial* object whose coordinates are already set, i.e. all of them -- so no caller can have depended on its behaviour.

There is no replacement. If you have a use for this, please contact the package maintainer; it can be implemented properly if there is interest.

Usage

transitions(p, agent)

Value

None. Signals an error.

Arguments

p

realized probability of persisting (i.e., either 0 or 1).

agent

SpatialPoints* object.

Author

Eliot McIntire