| transitions | R Documentation |
SELES - Transitioning to next time step (defunct)This function was never fully implemented and is now defunct: calling it signals an error.
It was intended to describe the probability of an agent successfully
persisting until the next time step, as a SELES-like function
maintaining conceptual backwards compatibility with
SELES. The implementation it carried could
not work – it assigned into sp::coordinates(agent), which errors on
any Spatial* object whose coordinates are already set, i.e. all of
them – so no caller can have depended on its behaviour.
There is no replacement. If you have a use for this, please contact the package maintainer; it can be implemented properly if there is interest.
transitions(p, agent)
p |
realized probability of persisting (i.e., either 0 or 1). |
agent |
|
None. Signals an error.
Eliot McIntire
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.