powered by
Currently, only Raster class has a useful method. Defaults to all(sapply(list(...)[-1], function(x) identical(list(...)[1], x)))
all(sapply(list(...)[-1], function(x) identical(list(...)[1], x)))
testEquivalentMetadata(...)
Invisible NULL. Called for its side effect: it signals an error if the objects' metadata are not equivalent, and returns silently if they are.
NULL
2 or more of the same type of object to test for equivalent metadata.